==> aliyun-java-sdk-green-3.6.5-sources.jar: com/aliyuncs/green/model/v20180509/VoiceAsyncManualScanResultsRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.green.model.v20180509;

import com.aliyuncs.RoaAcsRequest;
import com.aliyuncs.http.MethodType;
import com.aliyuncs.green.Endpoint;

/**
 * @author auto create
 * @version 
 */
public class VoiceAsyncManualScanResultsRequest extends RoaAcsRequest<VoiceAsyncManualScanResultsResponse> {
	   

	private String clientInfo;
	public VoiceAsyncManualScanResultsRequest() {
		super("Green", "2018-05-09", "VoiceAsyncManualScanResults", "green");
		setUriPattern("/green/voice/manual/scan/results");
		setMethod(MethodType.POST);
		try {
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointMap").set(this, Endpoint.endpointMap);
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointRegional").set(this, Endpoint.endpointRegionalType);
		} catch (Exception e) {}
	}

	public String getClientInfo() {
		return this.clientInfo;
	}

	public void setClientInfo(String clientInfo) {
		this.clientInfo = clientInfo;
		if(clientInfo != null){
			putQueryParameter("ClientInfo", clientInfo);
		}
	}

	@Override
	public Class<VoiceAsyncManualScanResultsResponse> getResponseClass() {
		return VoiceAsyncManualScanResultsResponse.class;
	}

}

==> aliyun-java-sdk-green-3.6.6-sources.jar: com/aliyuncs/green/model/v20180509/VoiceAsyncManualScanResultsRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.green.model.v20180509;

import com.aliyuncs.RoaAcsRequest;
import com.aliyuncs.http.MethodType;
import com.aliyuncs.green.Endpoint;

/**
 * @author auto create
 * @version 
 */
public class VoiceAsyncManualScanResultsRequest extends RoaAcsRequest<VoiceAsyncManualScanResultsResponse> {
	   

	private String clientInfo;
	public VoiceAsyncManualScanResultsRequest() {
		super("Green", "2018-05-09", "VoiceAsyncManualScanResults");
		setUriPattern("/green/voice/manual/scan/results");
		setMethod(MethodType.POST);
		try {
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointMap").set(this, Endpoint.endpointMap);
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointRegional").set(this, Endpoint.endpointRegionalType);
		} catch (Exception e) {}
	}

	public String getClientInfo() {
		return this.clientInfo;
	}

	public void setClientInfo(String clientInfo) {
		this.clientInfo = clientInfo;
		if(clientInfo != null){
			putQueryParameter("ClientInfo", clientInfo);
		}
	}

	@Override
	public Class<VoiceAsyncManualScanResultsResponse> getResponseClass() {
		return VoiceAsyncManualScanResultsResponse.class;
	}

}
